==> hs-uvector-0.1.1.0.tbz: lib/uvector-0.1.1.0/register.sh <==
#!/bin/sh

echo 'name: uvector
version: 0.1.1.0
license: BSD3
copyright:
maintainer: Don Stewart <dons@galois.com>
stability: experimental
homepage: http://code.haskell.org/~dons/code/uvector
package-url:
description: Fast unboxed arrays with a flexible interface.
             The library is built of fusible combinators, as
             described in the paper /Stream Fusion: From Lists to
             Streams to Nothing at All/.
             .
             For best results, compile with your user programs
             with -O2 -fvia-C -optc-O3.
category: Data
author: Manuel Chakravarty, Gabriele Keller, Roman Leshchinskiy, Don Stewart
exposed: True
exposed-modules: Data.Array.Vector Data.Array.Vector.UArr
hidden-modules: Data.Array.Vector.Prim.BUArr
                Data.Array.Vector.Prim.Debug Data.Array.Vector.Prim.Hyperstrict
                Data.Array.Vector.Prim.Text Data.Array.Vector.Stream
                Data.Array.Vector.Strict.Stream Data.Array.Vector.Strict.Basics
                Data.Array.Vector.Strict.Enum Data.Array.Vector.Strict.Sums
                Data.Array.Vector.Strict.Permute Data.Array.Vector.Strict.Text
import-dirs: /usr/local/lib/uvector-0.1.1.0/ghc-6.10.4
library-dirs: /usr/local/lib/uvector-0.1.1.0/ghc-6.10.4
hs-libraries: HSuvector-0.1.1.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/lib/uvector-0.1.1.0/ghc-6.10.4/include
includes: memcpy_extra.h
depends: base-4.1.0.0 ghc-prim-0.1.0.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/uvector-0.1.1.0/html/uvector.haddock
haddock-html: /usr/local/share/doc/uvector-0.1.1.0/html' | /usr/local/bin/ghc-pkg update -

==> hs-uvector-0.1.1.1.tbz: lib/uvector-0.1.1.1/register.sh <==
#!/bin/sh

echo 'name: uvector
version: 0.1.1.1
license: BSD3
copyright:
maintainer: Don Stewart <dons@galois.com>
stability: maintained
homepage: http://code.haskell.org/~dons/code/uvector
package-url:
description: Fast unboxed arrays with a flexible interface.
             The library is built of fusible combinators, as
             described in the paper /Stream Fusion: From Lists to
             Streams to Nothing at All/.
             .
             For best results, compile with your user programs
             with -O2 -fvia-C -optc-O3.
             .
             This library is deprecated: please consider using the
             vector package, <http://hackage.haskell.org/package/vector>.
category: Data
author: Manuel Chakravarty, Gabriele Keller, Roman Leshchinskiy, Don Stewart
exposed: True
exposed-modules: Data.Array.Vector Data.Array.Vector.UArr
hidden-modules: Data.Array.Vector.Prim.BUArr
                Data.Array.Vector.Prim.Debug Data.Array.Vector.Prim.Hyperstrict
                Data.Array.Vector.Prim.Text Data.Array.Vector.Stream
                Data.Array.Vector.Strict.Stream Data.Array.Vector.Strict.Basics
                Data.Array.Vector.Strict.Enum Data.Array.Vector.Strict.Sums
                Data.Array.Vector.Strict.Permute Data.Array.Vector.Strict.Text
import-dirs: /usr/local/lib/uvector-0.1.1.1/ghc-6.10.4
library-dirs: /usr/local/lib/uvector-0.1.1.1/ghc-6.10.4
              /usr/local/lib
hs-libraries: HSuvector-0.1.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/uvector-0.1.1.1/ghc-6.10.4/include
includes: memcpy_extra.h
depends: base-4.1.0.0 ghc-prim-0.1.0.0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/uvector-0.1.1.1/html/uvector.haddock
haddock-html: /usr/local/share/doc/uvector-0.1.1.1/html' | /usr/local/bin/ghc-pkg update -
